#
# spec file for package decker
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           decker-doc
Version:        1.41
Release:        1.3
Summary:        A multimedia sketchpad
License:        MIT
URL:            http://beyondloom.com/decker/
Source:         https://github.com/JohnEarnest/Decker/archive/refs/tags/v%{version}.tar.gz
BuildRequires:  decker
BuildArch:      noarch

%description
Decker is a multimedia platform for creating and sharing interactive documents, with sound, images, hypertext, and scripted behavior.

%prep
%autosetup -p1 -n Decker-%{version}

%build
lilt scripts/lildoc.lil docs/lil.md         docs/lil.html
lilt scripts/lildoc.lil docs/lilt.md        docs/lilt.html
lilt scripts/lildoc.lil docs/decker.md      docs/decker.html
lilt scripts/lildoc.lil docs/format.md      docs/format.html
lilt scripts/lildoc.lil docs/lilquickref.md docs/lilquickref.html

%install
mkdir -p %{buildroot}/%{_docdir}/decker
install --mode=644 docs/*.html %{buildroot}/%{_docdir}/decker
install -d examples/ %{buildroot}/%{_docdir}/decker

%files
%license LICENSE.txt
%doc Readme.md VERSION
%{_docdir}/decker 

%changelog
* Sun Mar 24 2024 vivid <absolutely.vivid@fastmail.org>
- Update decker and decker-doc to version 1.41
  * correct random[] in native-decker to select random rows of tables, rather than random col
  umns (which is very silly and almost never useful)
  * version bump to v1.41
  * make grid.rowvalue and grid.cellvalue writable, leveraging the generalizations of amend()
  , and in turn simplify the default handler for changecell[].
  * rework grid cell editing to occur in-situ instead of in a visibly distinct modal dialog. In some situations this may lead to a cramped field, and the current implementation prevents entering newlines, but despite these quibbles I think the overall experience- especially when using the keyboard- will be much nicer.
  * another weeklychallenge puzzle
  * introduce the changecell event for grids, replacing hardcoded validation logic with an overrideable default handler and providing opportunities for shimming in side effects.
  * compensate for rounding error when computing the width of the final cell in a grid with auto-sized columns.
  * generalize amending assignments to work for tables. Some of these operations are easy enough to express with 'update', but some would be extremely annoying. This generalization mostly follows from the behavior of amending lists/dicts.
  * remove some cruft from the test script
  * add a selection by cell mode to the grid widget, allowing it to behave a bit more like a traditional spreadsheet and permitting faster editing via the keyboard.
  * disable menu selection while hidden, per #82.
  * improve behavior of transparent grids on colored backgrounds by reducing reliance on color inversion, per #81.
  * auto-focus the script editor field when entering it via keyboard shortcuts, per #79.
  * gracefully handle grid widgets with 0-width columns, making this a viable method of hiding columns, if desired.
  * another weekly challenge problem, providing a nice example of progressive parsing.
  * show:none buttons should not be given a pointer mouse cursor.
  * extend dialogizer with configuration options for controlling text display speed and triggering sound effects.
* Sun Mar  3 2024 vivid <absolutely.vivid@fastmail.org>
- Update decker and decker-doc to version 1.40
- Remove install-script.patch - the patch was merged in upstream commit 7b1856ae8189c2247043cd433448ab1c2b30e49b
  * minor documentation touchups
  * introduce a 'like' primitive to Lil, loosely mirroring SQL's glob-matching operator. Since this is a new keyword it is a minor breaking change, and there is some functional overlap with parse pattern matching, but overall I think this addition will make a wide range of common use-cases simpler and more straightforward.
  * permit keyboard shortcuts to be activated while the menu is suppressed in drawing mode.
  * add danger.shell[]. offer not valid on Windows.
  * revise install script to accept DESTDIR/PREFIX vars and avoid the use of sudo.
  * an initial foray into exposing potentially hazardous (but equally useful) APIs to Decker. The 'danger zone' is presently accessible exclusively by rebuilding from source. In the future I may consider easier methods.
  * correct inconsistencies between web-decker and native-decker in how writecsv[] serialized 'j' formatted columns.
  * oops, actually native decker was already handling j column formats correctly; web-decker was busted.
  * fix web-decker not hiding toolbars while in modals or the script editor.
  * more refinements to puzzle solutions
  * make the j and a format symbols in a grid format string enclose their listy arguments before formatting. This makes, for example, a j format of a column of pairs do the right thing.
  * a simpler formulation of weekly challenge 127.1; are sets disjoint?
  * fix crashes if a prototype is removed while editing it.
* Wed Feb 28 2024 vivid <absolutely.vivid@fastmail.org>
- Update decker and decker-doc to version 1.39
  * checking in Puppeteer
  * introduce dictionary conforming to Lil
  * notes about set operations
  * fix description of raze-of-table
  * even more weekly challenge stuff
  * redefine the raze operator applied to a table to form a dictionary from the first two columns, if available.
  * patch possible UB in GIF decoder
  * make right-clicking with the fill tool erase (pattern 0) instead of using the fill color. In practice I've found this tremendously more useful, especially when working in transparency mask mode.
  * slightly nicer test framework
  * in some situations saving a deck would not necessarily reflect in-progress text editing operations.
  * make dialogizer respect the hidden state of its canvas when servicing a resize.
  * generalize deck.remove[] to accept widgets, removing them from whatever card they may reside within.
  * Lil solutions to the codereport 'top 10' problems.
  * more weekly challenge problems
  * more weekly challenge puzzles
  * extend the image interface with image.scale[], as a convenient chainable alternative to scaling images with image.paste[]
  * fix image export from the background image of a prototype.
  * allow image interfaces to be coerced (rtext.cat[] as well as internal rtext_cast()) to rtext runs containing an inline image.
  * when exporting images, clip the selection to the active container bounds.
  * make the 'Show Transparent' appearance of make Transparent+Invisible buttons not show an inverted background when clicked, making them less visible than ever before
  * when compact sliders are at their minimum or maximum extent, visibly disable the appropriate stepper button and its highlighting behavior.
  * more puzzle solutions
  * correct the vx := random NN instruction in the chip8 emulator example.
  * improve performance of readcsv[] by reducing unnecessary intermediate allocations.
  * a more efficient implementation of l_by(), which carries out the work of the 'by' clause in lil queries.
  * web-decker's random[] did not handle dicts like native-decker; they should be treated the same as lists.
* Sun Feb 25 2024 vivid <absolutely.vivid@fastmail.org>
- Don't strip the decker or lilt binaries
- Add decker-doc as a multibuild flavor instead of making it a separate package
* Sun Jan 14 2024 vivid <absolutely.vivid@fastmail.org>
- Create package at upstream version 1.37
  * more weekly challenge puzzles
  * correct a regression introduced in the last attempt at fixing event plumbing
  * simplify and improve the consistency of the cursor info overlay
  * correct prettyprinting floating-point numbers very close to whole integers
  * add an 'underpaint' mode that applies to all drawing tools. Underpainting leaves any instances of pattern 1 intact; this is ideal for coloring lineart, among other things
  * simplifying weekly challenge 247.2 by using the window[] helper function
